@@ -1,9 +1,13 @@
+#![ warn( missing_docs ) ]
+#![ warn( missing_debug_implementations ) ]
 
 // pub use is_slice::*;
 // // pub use instance_of::*;
 // #[cfg( feature = "inspect_type" )]
 // pub use inspect_type::*;
 
-pub use inspect_type::*;
-pub use is_slice::*;
-pub use implements::*;
+// pub use inspect_type::*;
+// pub use is_slice::*;
+// pub use implements::*;
+
+pub use typing_tools::*;
